### Name: mmcc2mmcp
### Title: MMCC Evaluation
### Aliases: mmcc2mmcp mmcc2cluster mmcp2pk mmcp2RMC mmcp2h mmcp2H mmcp2d
###   mmcp2D mmcp2i mmcp2I mmcp2cic mmcp2CIC mmcp2ALL mmcp2gsd mmcp2GSD cic
###   CIC mmcc MMCC gsd GSD
### Keywords: multivariate cluster

### ** Examples

cat("\nfake a cluster voting matrix\n")
c <- c(rbinom(4, 256, 0.25), rbinom(12, 256, 0.75))
c <- cbind(a=c, b=256-c)
c
mmcc2cluster(c)
table(mmcc2cluster(c))
cat("\nconvert to probabilities matrix\n")
p <- mmcc2mmcp(c)
p

cat("\nlook at Relative Model Complexity\n")
mmcp2RMC(p)

cat("\ncellwise Cluster Information Criterion\n")
mmcp2cic(p)
cat("\ncluster CIC\n")
colSums(mmcp2cic(p))
cat("\ncase CIC (aggregated by cluster)\n")
aggregate(rowSums(mmcp2cic(p)), by=list(mmcc2cluster(p)), FUN=mean)
cat("\ncalculating model CIC\n")
mean(rowSums(mmcp2cic(p)))
mmcp2CIC(p)
cat("\ncalculating all model statistics\n")
mmcp2ALL(p)
cat("\nGeneralized Silhouette Diagnostic\n")
mmcp2GSD(p)
boxplot(split(mmcp2gsd(p), mmcc2cluster(p)), main="GSD distribution by cluster")
boxplot(split(rowSums(mmcp2h(p)), mmcc2cluster(p)), main="Uncertainty distribution by cluster")

cat("\nshow that ties are broken at random\n")
c <- matrix(1, 16, 4)
table(mmcc2cluster(c))
table(mmcc2cluster(c))

cat("\ncompare some models differing in true and model complexity\n")
collect <- NULL
c <- matrix(1, 16, 1)
collect <- rbind(collect, "true=1  model=1"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=1  model=2"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=1  model=4"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=1  model=8"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=1  model=16"=mmcp2ALL(mmcc2mmcp(c)))
c <- t(matrix(rep(diag(2), 8), 2))
collect <- rbind(collect, "true=2  model=2"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=2  model=4"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=2  model=8"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=2  model=16"=mmcp2ALL(mmcc2mmcp(c)))
c <- t(matrix(rep(diag(4), 4), 4))
collect <- rbind(collect, "true=4  model=4"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=4  model=8"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=4  model=16"=mmcp2ALL(mmcc2mmcp(c)))
c <- t(matrix(rep(diag(8), 2), 8))
collect <- rbind(collect, "true=8  model=8"=mmcp2ALL(mmcc2mmcp(c)))
c <- cbind(c, c)
collect <- rbind(collect, "true=8  model=16"=mmcp2ALL(mmcc2mmcp(c)))
c <- diag(16)
collect <- rbind(collect, "true=16 model=16"=mmcp2ALL(mmcc2mmcp(c)))
colnames(collect)[c(5,6)] <- c("D*(1-RMC)=I","I-H=CIC")
print(collect[order(collect[,6]),])




